@@ -1,6 +1,6 @@
 #
 # Copyright (c) 1998-2000 John Aycock
-#  
+#
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
 # "Software"), to deal in the Software without restriction, including
@@ -8,10 +8,10 @@
 # distribute, sublicense, and/or sell copies of the Software, and to
 # permit persons to whom the Software is furnished to do so, subject to
 # the following conditions:
-# 
+#
 # The above copyright notice and this permission notice shall be
 # included in all copies or substantial portions of the Software.
-# 
+#
 # THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 # EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 # MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
@@ -20,7 +20,7 @@
 # TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 # SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
-__version__ = 'SPARK-0.6.1'
+__version__ = "SPARK-0.6.1"
 
 import re
 import sys
@@ -31,7 +31,7 @@ def _namelist(instance):
     for c in classlist:
         for b in c.__bases__:
             classlist.append(b)
-        #		for name in dir(c):
+        # 		for name in dir(c):
         for name in c.__dict__.keys():
             if name not in namedict:
                 namelist.append(name)
@@ -39,28 +39,28 @@ def _namelist(instance):
     return namelist
 
 
-class GenericScanner(object):
+class GenericScanner:
     def __init__(self):
         pattern = self.reflect()
         self.re = re.compile(pattern, re.VERBOSE)
 
         self.index2func = {}
         for name, number in self.re.groupindex.items():
-            self.index2func[number - 1] = getattr(self, 't_' + name)
+            self.index2func[number - 1] = getattr(self, "t_" + name)
 
     def makeRE(self, name):
         doc = getattr(self, name).__doc__
-        rv = '(?P<%s>%s)' % (name[2:], doc)
+        rv = f"(?P<{name[2:]}>{doc})"
         return rv
 
     def reflect(self):
         rv = []
         for name in _namelist(self):
-            if name[:2] == 't_' and name != 't_default':
+            if name[:2] == "t_" and name != "t_default":
                 rv.append(self.makeRE(name))
 
-        rv.append(self.makeRE('t_default'))
-        return '|'.join(rv)
+        rv.append(self.makeRE("t_default"))
+        return "|".join(rv)
 
     def error(self, s, pos):
         sys.stderr.write("Lexical error at position %s" % pos)
@@ -81,11 +81,11 @@ class GenericScanner(object):
             pos = m.end()
 
     def t_default(self, s):
-        r'( . | \n )+'
+        r"( . | \n )+"
         pass
 
 
-class GenericParser(object):
+class GenericParser:
     def __init__(self, start):
         self.rules = {}
         self.rule2func = {}
@@ -94,8 +94,8 @@ class GenericParser(object):
         self.startRule = self.augment(start)
         self.ruleschanged = 1
 
-    _START = 'START'
-    _EOF = 'EOF'
+    _START = "START"
+    _EOF = "EOF"
 
     #
     #  A hook for GenericASTBuilder and GenericASTMatcher.
@@ -108,13 +108,13 @@ class GenericParser(object):
 
         index = []
         for i in range(len(rules)):
-            if rules[i] == '::=':
+            if rules[i] == "::=":
                 index.append(i - 1)
         index.append(len(rules))
 
         for i in range(len(index) - 1):
             lhs = rules[index[i]]
-            rhs = rules[index[i] + 2:index[i + 1]]
+            rhs = rules[index[i] + 2 : index[i + 1]]
             rule = (lhs, tuple(rhs))
 
             rule, fn = self.preprocess(rule, func)
@@ -129,7 +129,7 @@ class GenericParser(object):
 
     def collectRules(self):
         for name in _namelist(self):
-            if name[:2] == 'p_':
+            if name[:2] == "p_":
                 func = getattr(self, name)
                 doc = func.__doc__
                 self.addRule(doc, func)
@@ -143,7 +143,7 @@ class GenericParser(object):
         startRule = (self._START, (start, self._EOF))
         self.rule2func[startRule] = lambda args: args[0]
         self.rules[self._START] = [startRule]
-        self.rule2name[startRule] = ''
+        self.rule2name[startRule] = ""
         return startRule
 
     def makeFIRST(self):
@@ -202,11 +202,11 @@ class GenericParser(object):
                 break
             self.buildState(tokens[i], states, i, tree)
 
-        #		_dump(tokens, states)
+        # 		_dump(tokens, states)
 
         if i < len(tokens) - 1 or states[i + 1] != [(self.startRule, 2, 0)]:
             # --ilya
-            #			del tokens[-1]
+            # 			del tokens[-1]
             self.error(tokens[i - 1])
         rv = self.buildTree(tokens, tree, ((self.startRule, 2, 0), i + 1))
         del tokens[-1]
@@ -235,7 +235,7 @@ class GenericParser(object):
                     prule, ppos, pparent = pitem
                     plhs, prhs = prule
 
-                    if prhs[ppos:ppos + 1] == (lhs,):
+                    if prhs[ppos : ppos + 1] == (lhs,):
                         new = prule, ppos + 1, pparent
                         if new not in state:
                             state.append(new)
@@ -273,9 +273,7 @@ class GenericParser(object):
                     continue
                 predicted[nextSym] = 1
 
-                ttype = token is not self._EOF and \
-                        self.typestring(token) or \
-                        None
+                ttype = token is not self._EOF and self.typestring(token) or None
                 if ttype is not None:
                     #
                     #  Even smarter predictor, when the
@@ -300,8 +298,7 @@ class GenericParser(object):
                                 state.append(new)
                                 continue
                         first = self.first[prhs0]
-                        if None not in first and \
-                                ttype not in first:
+                        if None not in first and ttype not in first:
                             continue
                         state.append(new)
                     continue
@@ -313,9 +310,7 @@ class GenericParser(object):
                     #  as good as FIRST sets though.
                     #
                     prhs = prule[1]
-                    if len(prhs) > 0 and \
-                            prhs[0] not in self.rules and \
-                            token != prhs[0]:
+                    if len(prhs) > 0 and prhs[0] not in self.rules and token != prhs[0]:
                         continue
                     state.append((prule, 0, i))
 
@@ -363,25 +358,23 @@ class GenericParser(object):
                 else:
                     child = children[0]
 
-                tokpos = self.buildTree_r(stack,
-                                          tokens, tokpos,
-                                          tree, child)
+                tokpos = self.buildTree_r(stack, tokens, tokpos, tree, child)
                 pos = pos - 1
                 (crule, cpos, cparent), cstate = child
                 state = cparent
 
         lhs, rhs = rule
-        result = self.rule2func[rule](stack[:len(rhs)])
-        stack[:len(rhs)] = [result]
+        result = self.rule2func[rule](stack[: len(rhs)])
+        stack[: len(rhs)] = [result]
         return tokpos
 
     def ambiguity(self, children):
         #
         #  XXX - problem here and in collectRules() if the same
-        #	 rule appears in >1 method.  But in that case the
-        #	 user probably gets what they deserve :-)  Also
-        #	 undefined results if rules causing the ambiguity
-        #	 appear in the same method.
+        # 	 rule appears in >1 method.  But in that case the
+        # 	 user probably gets what they deserve :-)  Also
+        # 	 undefined results if rules causing the ambiguity
+        # 	 appear in the same method.
         #
         sortlist = []
         name2index = {}
@@ -412,15 +405,18 @@ class GenericParser(object):
 #  XXX - silently overrides any user code in methods.
 #
 
+
 class GenericASTBuilder(GenericParser):
     def __init__(self, AST, start):
         GenericParser.__init__(self, start)
         self.AST = AST
 
     def preprocess(self, rule, func):
-        rebind = lambda lhs, self=self: \
-            lambda args, lhs=lhs, self=self: \
-                self.buildASTNode(args, lhs)
+        rebind = (
+            lambda lhs, self=self: lambda args, lhs=lhs, self=self: self.buildASTNode(
+                args, lhs
+            )
+        )
         lhs, rhs = rule
         return rule, rebind(lhs)
 
@@ -438,7 +434,7 @@ class GenericASTBuilder(GenericParser):
 
     def nonterminal(self, type, args):
         rv = self.AST(type)
-        rv[:len(args)] = args
+        rv[: len(args)] = args
         return rv
 
 
@@ -452,11 +448,12 @@ class GenericASTBuilder(GenericParser):
 #  preorder traversal.  Node type is determined via the typestring() method.
 #
 
+
 class GenericASTTraversalPruningException(Exception):
     pass
 
 
-class GenericASTTraversal(object):
+class GenericASTTraversal:
     def __init__(self, ast):
         self.ast = ast
 
@@ -471,7 +468,7 @@ class GenericASTTraversal(object):
             node = self.ast
 
         try:
-            name = 'n_' + self.typestring(node)
+            name = "n_" + self.typestring(node)
             if hasattr(self, name):
                 func = getattr(self, name)
                 func(node)
@@ -483,7 +480,7 @@ class GenericASTTraversal(object):
         for kid in node:
             self.preorder(kid)
 
-        name = name + '_exit'
+        name = name + "_exit"
         if hasattr(self, name):
             func = getattr(self, name)
             func(node)
@@ -495,7 +492,7 @@ class GenericASTTraversal(object):
         for kid in node:
             self.postorder(kid)
 
-        name = 'n_' + self.typestring(node)
+        name = "n_" + self.typestring(node)
         if hasattr(self, name):
             func = getattr(self, name)
             func(node)
@@ -513,15 +510,18 @@ class GenericASTTraversal(object):
 #  XXX - makes assumptions about how GenericParser walks the parse tree.
 #
 
+
 class GenericASTMatcher(GenericParser):
     def __init__(self, start, ast):
         GenericParser.__init__(self, start)
         self.ast = ast
 
     def preprocess(self, rule, func):
-        rebind = lambda func, self=self: \
-            lambda args, func=func, self=self: \
-                self.foundMatch(args, func)
+        rebind = (
+            lambda func, self=self: lambda args, func=func, self=self: self.foundMatch(
+                args, func
+            )
+        )
         lhs, rhs = rule
         rhslist = list(rhs)
         rhslist.reverse()
@@ -538,12 +538,12 @@ class GenericASTMatcher(GenericParser):
 
         for child in node:
             if children == 0:
-                self.input.insert(0, '(')
+                self.input.insert(0, "(")
             children = children + 1
             self.match_r(child)
 
         if children > 0:
-            self.input.insert(0, ')')
+            self.input.insert(0, ")")
 
     def match(self, ast=None):
         if ast is None:
@@ -562,15 +562,15 @@ class GenericASTMatcher(GenericParser):
 
 def _dump(tokens, states):
     for i in range(len(states)):
-        print('state', i)
+        print("state", i)
         for (lhs, rhs), pos, parent in states[i]:
-            print('\t', lhs, '::='),
-            print(' '.join(rhs[:pos])),
-            print('.'),
-            print(' '.join(rhs[pos:])),
-            print(',', parent, '.', pos)
-        #			print(',', parent
+            print("\t", lhs, "::="),
+            print(" ".join(rhs[:pos])),
+            print("."),
+            print(" ".join(rhs[pos:])),
+            print(",", parent, ".", pos)
+        # 			print(',', parent
         if i < len(tokens):
-            print('')
-            print('token', str(tokens[i]))
-            print('')
+            print("")
+            print("token", str(tokens[i]))
+            print("")
